@@ -92,7 +92,7 @@ private:
     QString VK_getCapsFilter();
     QString VK_getMuxer();
     QString Vk_get_Videocodec_Encoder();
-    QString VK_getVideoScale();
+    QString VK_scale();
 
     QFileSystemWatcher *videoFileSystemWatcher;
 
