@@ -80,8 +80,8 @@ QvkPlayer::QvkPlayer( QMainWindow *parent, Ui_formMainWindow *ui_mainwindow ) :
     ui->pushButtonPlay->setIcon( QIcon::fromTheme( "media-playback-start" , style()->standardIcon( QStyle::SP_MediaPlay ) ) );
     ui->pushButtonPause->setIcon( QIcon::fromTheme( "media-playback-pause", style()->standardIcon( QStyle::SP_MediaPause ) ) );
     ui->pushButtonStop->setIcon( QIcon::fromTheme( "media-playback-stop"  , style()->standardIcon( QStyle::SP_MediaStop ) ) );
-    ui->toolButtonFrameBackward->setIcon( QIcon::fromTheme( "go-previous",  style()->standardIcon( QStyle::SP_MediaSkipBackward ) ) );
-    ui->toolButtonFrameForward->setIcon( QIcon::fromTheme( "go-next",       style()->standardIcon( QStyle::SP_MediaSkipForward ) ) );
+    ui->toolButtonFrameBackward->setIcon( QIcon::fromTheme( "go-previous",  style()->standardIcon( QStyle::SP_MediaSeekBackward ) ) );
+    ui->toolButtonFrameForward->setIcon( QIcon::fromTheme( "go-next",       style()->standardIcon( QStyle::SP_MediaSeekForward ) ) );
     ui->toolButtonOpenFile->setIcon( QIcon::fromTheme( "document-open",     style()->standardIcon( QStyle::SP_FileIcon ) ) );
     ui->toolButtonMute->setIcon( QIcon::fromTheme( "audio-volume-high"    , style()->standardIcon( QStyle::SP_MediaVolume ) ) );
     ui->toolButtonFullscreen->setIcon( QIcon::fromTheme( "view-fullscreen", QIcon( ":/pictures/player/fullscreen.png" ) ) );
@@ -537,7 +537,7 @@ void QvkPlayer::slot_setNewImage( QImage image )
     QSize ratioSize = getPixelaspectRatio();
     qreal ratio = (qreal)ratioSize.width() / (qreal)ratioSize.height();
     QScreen *screen = QGuiApplication::primaryScreen();
-    if ( ratio == 1 )
+    if ( ratio == 1.0 )
     {
         image.setDevicePixelRatio( screen->devicePixelRatio() );
         image = image.scaled( static_cast<int>( ui->framePlayer->width()*screen->devicePixelRatio() ),
@@ -551,7 +551,7 @@ void QvkPlayer::slot_setNewImage( QImage image )
     // Testvideos find in source code under /vokoscreenNG/Videos-to-test-the-player/
     // Example:
     // Area:450x800 scale:1280*720
-    if ( ( ratio != 1 ) and ( ratioSize.width() < ratioSize.height() ) )
+    if ( ( ratio != 1.0 ) and ( ratioSize.width() < ratioSize.height() ) )
     {
         // Adapt to the frame
         if ( ui->framePlayer->width() < (int)( (qreal)ui->framePlayer->height() * ( (qreal)image.width() / (qreal)image.height() * ratio ) * screen->devicePixelRatio() ) )
@@ -578,7 +578,7 @@ void QvkPlayer::slot_setNewImage( QImage image )
 
     // Example:
     // Area:800x320 scale:1280*720
-    if ( ( ratio != 1 ) and ( ratioSize.width() > ratioSize.height() ) )
+    if ( ( ratio != 1.0 ) and ( ratioSize.width() > ratioSize.height() ) )
     {
         // Adapt to the frame
         if ( ui->framePlayer->height() < (int)( (qreal)ui->framePlayer->width() * ( (qreal)image.height() / (qreal)image.width() / ratio ) * screen->devicePixelRatio() ) )
